PRICEIT
Author: David WANG
Version 0.0.1

This is a project to extract realtime price of stocks and crypto currencies.

Usage sample:
    print(getprice('TSLA'))
    print(getprice('BTC-USD'))

Running result:

['TSLA', 1086.17, 'Nasdaq Real Time Price', '2022-01-12 09:33:34']

['BTC-USD', 43810.18, 'CoinMarketCap', '2022-01-12 09:32:00']